from edps import subworkflow, task, qc1calib, ReportInput

from .eris_datasources import *
from .eris_task_function import *


@subworkflow("image_quality_nix", "")
def image_quality_nix(dark_nix, linearity_nix, nix_flat_lamp, nix_flat_twilight, nix_flat_sky):
    # Compute persistence correction.
    persistence_nix = (task('persistence_nix')
                       .with_recipe('eris_persistence_monitor')
                       .with_report("eris_rawdisp", ReportInput.RECIPE_INPUTS)
                       .with_dynamic_parameter("which_mode", which_mode)
                       .with_dynamic_parameter("which_speed", which_speed)
                       .with_main_input(raw_persistence_nix)
                       .with_associated_input(dark_nix, [MASTER_DARK_IMG], condition=is_nix_slow,
                                              match_rules=match_nix_dark_persistence_slow)
                       .with_associated_input(dark_nix, [MASTER_DARK_IMG], condition=is_nix_fast,
                                              match_rules=match_nix_dark_persistence_fast)
                       .with_input_filter(MASTER_DARK_IFU, MASTER_DARK_IMG)
                       .with_job_processing(set_persistence)
                       .with_meta_targets([qc1calib])
                       .build())

    # --- Reduce NIX pupil frames ----------------------------------------------------------------------
    pupil_nix = (task('pupil_nix')
                 .with_recipe('eris_nix_pupil')
                 .with_report("eris_rawdisp", ReportInput.RECIPE_INPUTS)
                 .with_main_input(raw_pupil_nix)
                 .with_associated_input(linearity_nix, [GAIN_INFO, COEFFS_CUBE, BP_MAP_NL])
                 .with_associated_input(dark_nix, [MASTER_DARK_IMG])
                 .with_dynamic_parameter("band_used", which_band)
                 .with_associated_input(nix_flat_twilight, [MASTER_FLAT_TWILIGHT_LOFREQ], condition=is_short_general)
                 .with_associated_input(nix_flat_lamp,
                                        [MASTER_FLAT_LAMP_HIFREQ, MASTER_FLAT_LAMP_LOFREQ, MASTER_BPM_LAMP],
                                        min_ret=1, condition=is_short_general)
                 .with_associated_input(nix_flat_sky,
                                        [MASTER_FLAT_SKY_HIFREQ, MASTER_SKY_LOFREQ, MASTER_BPM_SKY],
                                        min_ret=1, condition=is_long, match_rules=match_nix_skyflat)
                 .with_associated_input(nix_flat_sky,
                                        [MASTER_FLAT_SKY_HIFREQ, MASTER_SKY_LOFREQ, MASTER_BPM_SKY],
                                        min_ret=1, condition=is_long_bra, match_rules=match_skyflat_long_bra)
                 .with_input_filter(GAIN_INFO, COEFFS_CUBE, BP_MAP_NL, MASTER_FLAT_LAMP_HIFREQ, MASTER_FLAT_LAMP_LOFREQ,
                                    MASTER_BPM_LAMP, MASTER_DARK_IMG, MASTER_FLAT_TWILIGHT_LOFREQ)
                 .with_associated_input(nix_wcs_matched_catalogue)
                 .with_associated_input(nix_wcs_refine)
                 .with_meta_targets([qc1calib])
                 .build())

    pupil_monitor_nix = (task('pupil_monitor_nix')
                        # .with_recipe('eris_nix_pupil_monitor')
                         .with_main_input(pupil_nix)
                         .with_dynamic_parameter("which_nxpw", which_nxpw)
                         .with_associated_input(nix_pupil_reference)
                         .with_associated_input(nix_sam_info, condition=is_sam)
                         .with_meta_targets([qc1calib])
                         .build())

    return persistence_nix, pupil_nix, pupil_monitor_nix
